# Sgraphic - Simple graphic

![simple graphics exaple](img/example.png)

##  Very simple 2d graphics package
Basically just a wrapper of the brilliant [skia python](https://github.com/kyamagu/skia-python) package.
This package exist because i needed a simple 2d graphic plotter with Ipython support and matplotlib inspired syntax.
[P5py](https://github.com/p5py/p5) is close but it is slow and does not support anti-aliasing yet.

SG can't do a lot yet but it is simple and fast.

Does not support interaction or 3d.

## Installation
Run:

``pip install sgraphic``

## Comming:
 - Animation support
 - Documentation


## Documentation
[Will be released later here](https://renetc.github.io/Simple-graphics/)

## Requires
- python 3
- skia-python
- IPython
- PIL
- numpy
- easing-function

<!--

medium
https://thucnc.medium.com/how-to-publish-your-own-python-package-to-pypi-4318868210f9

update
https://stackoverflow.com/questions/57411888/how-to-update-pip-package

cp -a /home/renec/anaconda3/lib/python3.7/site-packages/sg/. /home/renec/Drive/Dokumenter/pip_sg/sgraphic


-->
